@@ -209,6 +209,7 @@ class PreRecordRequest(BaseModel):
     roistat_first: Optional[str]
     with_discount: bool = True
     gift_code: str = ""
+    initial_cost: Optional[int]
 
     class Config:
         use_enum_values = True
@@ -306,7 +307,7 @@ class ClientPreRecordsRequest(BaseModel):
         client_uuid = values.get("client_uuid")
         phone = values.get("phone")
         if not client_uuid and not phone:
-            raise ValueError("All fields are empty")
+            raise ValueError("phone or client_uuid is required")
         return values
 
 
@@ -318,6 +319,12 @@ class LabService(BaseModel):
     price_code: str
 
 
+class OrderResults(BaseModel):
+    lab_results_url: Optional[str]
+    covid_results_url: Optional[str]
+    flg_results_url: Optional[str]
+
+
 class PreRecordResponse(BaseModel):
     number: int
     phone: str
@@ -329,6 +336,7 @@ class PreRecordResponse(BaseModel):
     prepayment_cost: Optional[int]
     pay_type: PayType
     visit_cost: Optional[int]
+    initial_cost: Optional[int]
     pay_system: Optional[PaySystem]
     pay_service_id: Optional[str]
     med_center_id: int
@@ -342,6 +350,8 @@ class PreRecordResponse(BaseModel):
     place: int
     extra_fields: Optional[LabExtraFields]
     covid_fields: Optional[CovidFields]
+    results: Optional[OrderResults]
+    dc: datetime.datetime
 
     class Config:
         use_enum_values = True
